@@ -24,6 +24,10 @@ from requests.packages.urllib3.util.retry import Retry
 import inforion.ionapi.controller as controller
 import inforion.helper.filehandling as filehandling
 
+from openpyxl import load_workbook
+from openpyxl import Workbook
+from openpyxl.chart import BarChart, Series, Reference
+
 # import sendresults, saveresults
 # from inforion.ionapi.model import
 
@@ -41,16 +45,11 @@ def execute(
     df = df.astype(str)
 
     data = {"program": program, "cono": 409}
-
-    mylist = []
     data1 = {}
-    data2 = {}
     a = []
 
     chunk = MaxChunk
     if end is not None:
-        # total_rows = end - start
-        counter = 0
         df = df[start:end].copy(deep=False)
         df = df.reset_index(drop=True)
         # print (df.head(10))
@@ -105,6 +104,9 @@ def execute(
         print("Save to file: " + outputfile)
         filehandling.savetodisk(outputfile, df)
 
+        df_results = getSuccessGraphDataframe(df)
+        createGraph(outputfile, df_results)
+
     return df
 
 
@@ -117,16 +119,11 @@ def executeSnd(
     data = {"program": program, "cono": 409}
 
     methode = methode.split(",")
-    methode_count = len(methode)
-
-    mylist = []
+    len(methode)
     data1 = {}
-    data2 = {}
 
     chunk = MaxChunk
     if end is not None:
-        # total_rows = end - start
-        counter = 0
         df = df[start:end].copy(deep=False)
         df = df.reset_index(drop=True)
 
@@ -181,16 +178,9 @@ def executeAsyncSnd(
     data = {"program": program, "cono": 409}
 
     methode = methode.split(",")
-    methode_count = len(methode)
-
-    mylist = []
+    len(methode)
     data1 = {}
-    data2 = {}
-
-    chunk = MaxChunk
     if end is not None:
-        # total_rows = end - start
-        counter = 0
         df = df[start:end].copy(deep=False)
         df = df.reset_index(drop=True)
         # print (df.head(10))
@@ -237,3 +227,69 @@ def executeAsyncSnd(
     return df
 
     """
+
+def getSuccessGraphDataframe(df):
+    results = {}
+    for _, row in df.iterrows():
+        msgs = row['MESSAGE'].split('|')
+        for msg in msgs:
+            if(msg):
+                key = msg[0:msg.index(':')]
+                val = msg[msg.index(':')+1:]
+
+                if key not in results:
+                    results[key] = {}
+                    results[key]['success'] = 0
+                    results[key]['fail'] = 0
+
+                if('OK' in val or 'ist bereits vorhanden' in val ):
+                    results[key]['success'] = results[key]['success'] + 1
+                else:
+                    results[key]['fail'] = results[key]['fail'] + 1
+
+
+    success = []
+    fail = []
+    prog = []
+    for key in results:
+        prog.append(key)
+        success.append(results[key]['success'])
+        fail.append(results[key]['fail'])
+
+    df = pd.DataFrame({'success': success,
+                'fail': fail}, index=prog)
+    return df
+
+
+def createGraph(excel_file, df):
+    sheet_name = 'Data'
+    sheet_name_graphs = 'Graphs'
+
+    writer = pd.ExcelWriter(excel_file, engine='openpyxl')
+    book = load_workbook(excel_file)
+    writer.book = book
+    writer.sheets = dict((ws.title, ws) for ws in book.worksheets)
+    ws_graph = writer.book.create_sheet(sheet_name_graphs)
+    df.to_excel(writer, sheet_name=sheet_name)
+
+    ws = writer.sheets[sheet_name]
+    
+    chart1 = BarChart()
+    chart1.type = "col"
+    chart1.style = 10
+    chart1.title = "ETL Results"
+    chart1.y_axis.title = 'Count'
+    chart1.x_axis.title = 'Programm'
+
+    data = Reference(ws, min_col=2, min_row=1, max_row=7, max_col=3)
+    cats = Reference(ws, min_col=1, min_row=2, max_row=7)
+    chart1.add_data(data, titles_from_data=True)
+    chart1.set_categories(cats)
+    chart1.shape = 4
+    chart1.height = 12
+    chart1.width = 20
+    #chart1.x_axis = 10
+    #chart1.y_axis = 10
+
+    ws_graph.add_chart(chart1, "A10")
+    writer.save()
